==> rospell-2007.02.rc1.tar.gz: rospell-2007.02.rc1/src/rospell/wwwdialog.cpp <==
//*********************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//*********************************************************************

#include "wwwdialog.h"
#ifdef USING_QT3
#include <qlayout.h>
#include <qlabel.h>
#include <qhbox.h>
#include <qaccel.h>
#endif
#ifdef USING_QT4
#include <Q3VBoxLayout>
#include <QLabel>
#include <q3hbox.h>
#include <q3accel.h>
#endif

#include <qlineedit.h>
#include <qpushbutton.h>
#include <qgroupbox.h>


//*****************************************************************************/
// alias dialog
//*****************************************************************************/
WWWDialog::WWWDialog(): QDialog(0, "alias", true) {
	Q3VBoxLayout *vly = new Q3VBoxLayout(this, 10);
	vly->setAutoAdd(true);
	
	QGroupBox *box1 = new QGroupBox(1, QGroupBox::Horizontal, "Proxy", this);	
	// proxy address
	Q3HBox *hbox1 = new Q3HBox(box1);
	hbox1->setSpacing(10);
	label1_ = new QLabel("address: http://", hbox1);
	proxy_ = new QLineEdit(hbox1);
	// proxy port
	Q3HBox *hbox2 = new Q3HBox(box1);
	hbox2->setSpacing(10);
	label2_ = new QLabel("port: ", hbox2);
	proxy_port_ = new QLineEdit(hbox2);


	QGroupBox *box2 = new QGroupBox(1, QGroupBox::Horizontal, "Authentication", this);	
	// user name
	Q3HBox *hbox3 = new Q3HBox(box2);
	hbox3->setSpacing(10);
	label3_ = new QLabel("user name: ", hbox3);
	username_ = new QLineEdit(hbox3);
	// password
	Q3HBox *hbox4 = new Q3HBox(box2);
	hbox4->setSpacing(10);
	label4_ = new QLabel("password: ", hbox4);
	password_ = new QLineEdit(hbox4);
	password_->setEchoMode(QLineEdit::Password);

	// accept/reject
	Q3HBox *hbox5 = new Q3HBox(this);
	hbox5->setSpacing(10);
	// some empty space
	(new QWidget(hbox5))->setMinimumWidth(80);
	(new QWidget(hbox5))->setMinimumWidth(80);
	button_ok_ = new QPushButton("Ok", hbox5);
	button_cancel_ = new QPushButton("Cancel", hbox5);

	connect(button_ok_, SIGNAL(clicked()), SLOT(clicked_ok()));
	connect(button_cancel_, SIGNAL(clicked()), SLOT(reject()));
}


void WWWDialog::clicked_ok() {
//setenv("http_proxy", "http://user:password@proxy_ip_address:proxy_port", 1);
	if (proxy_->text().isEmpty()) {
		unsetenv("http_proxy");
		accept();
		return;
	}
	
	QString env_val = "http://";
	if (!username_->text().isEmpty() && !password_->text().isEmpty())
		env_val += username_->text() + ":" + password_->text() + "@";
	env_val += proxy_->text();
	if (!proxy_port_->text().isEmpty())
		env_val += ":" + proxy_port_->text();
//printf("%s\n", (const char *) env_val);
	setenv("http_proxy", (const char *) env_val, 1);		
	accept();
}

==> rospell-2009.00-rc2.tar.gz: rospell-2009.00-rc2/src/rospell/wwwdialog.cpp <==
//*********************************************************************
// Copyright (C) 2005,  Lucian Constantin <struct_bylighting@yahoo.com>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later
// version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//*********************************************************************

#include "wwwdialog.h"
#ifdef USING_QT3
#include <qlayout.h>
#include <qlabel.h>
#include <qhbox.h>
#include <qaccel.h>
#endif
#ifdef USING_QT4
#include <Q3VBoxLayout>
#include <QLabel>
#include <q3hbox.h>
#include <q3accel.h>
#endif

#include <qlineedit.h>
#include <qpushbutton.h>
#include <qgroupbox.h>


//*****************************************************************************/
// alias dialog
//*****************************************************************************/
WWWDialog::WWWDialog(): QDialog(0, "proxy", true) {
#ifndef ROSPELL_NO_WGET
	Q3VBoxLayout *vly = new Q3VBoxLayout(this, 10);
	vly->setAutoAdd(true);

	QGroupBox *box1 = new QGroupBox(1, QGroupBox::Horizontal, tr("Proxy: "), this);
	// proxy address
	Q3HBox *hbox1 = new Q3HBox(box1);
	hbox1->setSpacing(10);
	label1_ = new QLabel(tr("address: http://"), hbox1);
	proxy_ = new QLineEdit(hbox1);
	// proxy port
	Q3HBox *hbox2 = new Q3HBox(box1);
	hbox2->setSpacing(10);
	label2_ = new QLabel("port: ", hbox2);
	proxy_port_ = new QLineEdit(hbox2);


	QGroupBox *box2 = new QGroupBox(1, QGroupBox::Horizontal, tr("Authentication: "), this);
	// user name
	Q3HBox *hbox3 = new Q3HBox(box2);
	hbox3->setSpacing(10);
	label3_ = new QLabel(tr("user name: "), hbox3);
	username_ = new QLineEdit(hbox3);
	// password
	Q3HBox *hbox4 = new Q3HBox(box2);
	hbox4->setSpacing(10);
	label4_ = new QLabel(tr("password: "), hbox4);
	password_ = new QLineEdit(hbox4);
	password_->setEchoMode(QLineEdit::Password);

	// accept/reject
	Q3HBox *hbox5 = new Q3HBox(this);
	hbox5->setSpacing(10);
	// some empty space
	(new QWidget(hbox5))->setMinimumWidth(80);
	(new QWidget(hbox5))->setMinimumWidth(80);
	button_ok_ = new QPushButton(tr("OK"), hbox5);
	button_cancel_ = new QPushButton(tr("Cancel"), hbox5);

	connect(button_ok_, SIGNAL(clicked()), SLOT(clicked_ok()));
	connect(button_cancel_, SIGNAL(clicked()), SLOT(reject()));
#endif
}


void WWWDialog::clicked_ok() {
#ifndef ROSPELL_NO_WGET
//setenv("http_proxy", "http://user:password@proxy_ip_address:proxy_port", 1);
	if (proxy_->text().isEmpty()) {
		unsetenv("http_proxy");
		accept();
		return;
	}

	QString env_val = "http://";
	if (!username_->text().isEmpty() && !password_->text().isEmpty())
		env_val += username_->text() + ":" + password_->text() + "@";
	env_val += proxy_->text();
	if (!proxy_port_->text().isEmpty())
		env_val += ":" + proxy_port_->text();
//printf("%s\n", (const char *) env_val);
	setenv("http_proxy", (const char *) env_val, 1);
	accept();
#endif
}
